# Changelog

<!--next-version-placeholder-->

## v0.6.0 (2022-11-25)
### Feature
* Commit changes to github ([`a9d06d5`](https://github.com/rob-luke/conversations/commit/a9d06d5747ce36074831cb779af199f5f1ba366d))
